@@ -12,13 +12,13 @@ fi
 if [ -z "$ADTTMP" ]; then
   export PATH="$SRCDIR/blib/script":"$SRCDIR/zgz":"$PATH"
   export PERL5LIB="$SRCDIR/blib/lib"
-  {
+  (
     set -e
     if [ ! -f Makefile ]; then
       perl Makefile.PL
     fi
-    make
-  }
+    make -s
+  )
 fi
 
 
@@ -38,11 +38,13 @@ get_sha1() {
 
 git_init() {
   local repo="$1"
+  cd "$TMPDIR"
   mkdir "$repo"
   cd "$repo"
   git init
   git config user.name 'Test User'
   git config user.email 'test@example.com'
+  REPODIR="$TMPDIR/$repo"
 }
 
 import_tarball() {
@@ -59,3 +61,17 @@ assertHashEquals() {
   sha1_2=$(get_sha1 "$2")
   assertEquals "$sha1_1" "$sha1_2"
 }
+
+assertSuccess() {
+  (>&2 echo "I: assertSuccess($@)")
+  "$@"
+  rc=$?
+  assertEquals 0 "$rc"
+}
+
+assertFailure() {
+  (>&2 echo "I: assertFailure($@)")
+  "$@"
+  rc=$?
+  assertNotEquals 0 "$rc"
+}
